@@ -70,7 +70,23 @@ from bidsphysio.base.bidsphysio import (PhysioSignal,
                                         PhysioData)
 
 
-def dcm2bids( physio_dcm, bids_prefix, verbose=False ):
+def dcm2bids( physio_dcm, verbose=False ):
+    """Reads the physiological data from either a CMRR DICOM file or
+    from a series of CMRR .log files and stores it in a PhysioData
+    member.
+
+    Parameters
+    ----------
+    physio_dcm : list of str
+        List of paths of the original physio files (or single path)
+    verbose : bool
+        Verbose output flag.
+
+    Returns
+    -------
+    physio : PhysioData
+        PhysioData with the contents of the file
+    """
 
     # Because a physio DICOM file contains all of the physio channels, we can
     # only handle a single DICOM file per bids_prefix. So check that we have
@@ -150,8 +166,8 @@ def dcm2bids( physio_dcm, bids_prefix, verbose=False ):
             physio_log_lines = log_bytes.decode('utf-8', 'ignore').splitlines()
 
             # Parse physio_log_lines
-            waveform_name, t, s, dt = parse_log(physio_log_lines, verbose=verbose)
-            physio_label, physio_signal, first_trigger_this_waveform = to_physiosignal(waveform_name, t, s, dt)
+            uuid, waveform_name, t, s, dt = parse_log(physio_log_lines, verbose=verbose)
+            physio_label, physio_signal, first_trigger_this_waveform = to_physiosignal(uuid, waveform_name, t, s, dt)
             t_first_trigger = t_first_trigger or first_trigger_this_waveform
             if physio_label:
                 physio.append_signal(physio_signal)
@@ -163,8 +179,8 @@ def dcm2bids( physio_dcm, bids_prefix, verbose=False ):
             physio_log_lines = [line.rstrip() for line in open(f)]
 
             # Parse physio_log_lines
-            waveform_name, t, s, dt = parse_log(physio_log_lines, verbose=verbose)
-            physio_label, physio_signal, first_trigger_this_waveform = to_physiosignal(waveform_name, t, s, dt)
+            uuid, waveform_name, t, s, dt = parse_log(physio_log_lines, verbose=verbose)
+            physio_label, physio_signal, first_trigger_this_waveform = to_physiosignal(uuid, waveform_name, t, s, dt)
             t_first_trigger = t_first_trigger or first_trigger_this_waveform
             if physio_label:
                 physio.append_signal(physio_signal)
@@ -176,10 +192,7 @@ def dcm2bids( physio_dcm, bids_prefix, verbose=False ):
         # we also fill with NaNs the places for which there is missing data:
         p_signal.plug_missing_data()
 
-    # Save files:
-    physio.save_to_bids_with_trigger( bids_prefix )
-
-    return
+    return physio
 
 
 def parse_log(physio_log, verbose=False):
@@ -249,10 +262,35 @@ def parse_log(physio_log, verbose=False):
         print('Waveform type   : %s' % waveform_name)
 
     # Return numpy arrays
-    return waveform_name, np.array(t_list), np.array(s_list), dt
+    return uuid, waveform_name, np.array(t_list), np.array(s_list), dt
 
 
-def to_physiosignal(waveform_name, t, s, dt):
+def get_acq_time(physio_file):
+    """
+    Function to get the acquisition time of a '.log' file
+    Inputs:
+    ------
+    physio_file : str or Path
+        Name of the physio file
+
+    Returns:
+    -------
+    acq_time : float or None
+        Time of the beginning of the physiological acquisition
+    """
+    with open(physio_file,'r') as f:
+        for line in f:
+            if line.startswith('ScanDate'):
+                acq_date_time = line.rsplit()[-1]
+                break
+    if acq_date_time:
+        acq_time = float(acq_date_time.split('_')[-1])
+    else:
+        acq_time = None
+    return acq_time
+
+
+def to_physiosignal(uuid, waveform_name, t, s, dt):
 
     t_first_trigger = None
 
@@ -274,6 +312,7 @@ def to_physiosignal(waveform_name, t, s, dt):
 
     physio_signal = PhysioSignal(
                 label=physio_label,
+                uuid=uuid,
                 samples_per_second=1000 / dt,  # dt is in ms.
                 sampling_times=t / 1000,
                 physiostarttime=t[0] / 1000,
@@ -295,7 +334,7 @@ def main():
     # make sure input files exist:
     for infile in args.infiles:
         if not os.path.exists(infile):
-            raise FileNotFoundError( '{i} file not found'.format(i=infile))
+            raise FileNotFoundError('{i} file not found'.format(i=infile))
 
     # make sure output directory exists:
     odir = os.path.dirname(args.bidsprefix)
@@ -303,7 +342,9 @@ def main():
         if not os.path.exists(odir):
             os.makedirs(odir)
 
-    dcm2bids( args.infiles, args.bidsprefix, verbose=args.verbose )
+    physio_data = dcm2bids(args.infiles, verbose=args.verbose)
+    if physio_data.labels():
+        physio_data.save_to_bids_with_trigger(args.bidsprefix)
 
 
 # This is the standard boilerplate that calls the main() function.
